from typing import Optional


class Traits(object):

    def __init__(
        self,                       # type: Traits
        customer_call_by=None,      # type: Optional[CustomerCallBy]
        qr_code_url=None,           # type: Optional[QrCodeUrl]
    ):
        # type: (...) -> None

        self.customer_call_by = customer_call_by
        self.qr_code_url = qr_code_url


class CustomerCallBy(object):

    def __init__(
        self,           # type: CustomerCallBy
        reference,      # type: str
    ):
        # type: (...) -> None

        self.reference = reference


class QrCodeUrl(object):

    def __init__(
        self,           # type: QrCodeUrl
        reference,      # type: str
    ):
        # type: (...) -> None

        self.reference = reference
