from ._CustomProperty import CustomProperty
from typing import List


class ItemToSell(object):

    def __init__(
        self,                       # type: ItemToSell
        part_code,                  # type: int
        quantity,                   # type: float
        custom_properties=None,     # type: List[CustomProperty] | None
    ):
        # type: (...) -> None

        self.part_code = part_code
        self.quantity = quantity
        self.custom_properties = custom_properties or []
