from messagebus import TokenCreator, TokenPriority

POS_CONTROL_GROUP = "5"

TK_POS_GET_MODEL = TokenCreator.create_token(
    priority=TokenPriority.high,
    message_group=POS_CONTROL_GROUP,
    number="1"
)

TK_POS_BUSINESSBEGIN = TokenCreator.create_token(
    priority=TokenPriority.high,
    message_group=POS_CONTROL_GROUP,
    number="8"
)

TK_POS_BUSINESSEND = TokenCreator.create_token(
    priority=TokenPriority.high,
    message_group=POS_CONTROL_GROUP,
    number="9"
)

TK_POS_USERLOGIN = TokenCreator.create_token(
    priority=TokenPriority.high,
    message_group=POS_CONTROL_GROUP,
    number="A"
)

TK_POS_USERLOGOUT = TokenCreator.create_token(
    priority=TokenPriority.high,
    message_group=POS_CONTROL_GROUP,
    number="C"
)

TK_POS_USEROPEN = TokenCreator.create_token(
    priority=TokenPriority.high,
    message_group=POS_CONTROL_GROUP,
    number="12"
)

TK_POS_GETCONFIG = TokenCreator.create_token(
    priority=TokenPriority.high,
    message_group=POS_CONTROL_GROUP,
    number="16",
)

TK_POS_LISTUSERS = TokenCreator.create_token(
    priority=TokenPriority.high,
    message_group=POS_CONTROL_GROUP,
    number="17"
)
