from typing import Optional

from ._OperatorState import OperatorState


class Operator(object):
    def __init__(
        self,        # type: Operator
        id,          # type: int
        name,        # type: str
        level,       # type: Optional[int]
        state,       # type: OperatorState
        session_id,  # type: str
    ):
        self.id = id
        self.name = name
        self.level = level
        self.state = state
        self.session_id = session_id
